@@ -6,23 +6,56 @@
 import tornado.web
 import tornado.ioloop
 
+from inspect import isclass
 from tornado.httpserver import HTTPServer
 from optparse import OptionParser, OptionGroup
 from router import load_handlers
 from context import LogicContext
-from utility import reflesh_config, app_path, set_default_encoding
+from utility import refresh_config, app_path, set_default_encoding,get_members
 
+def get_ui_modules():
+    """
+    return ui module members in ACTION_DIR
+    """
+    m_filter = lambda m: isclass(m) and issubclass(m,tornado.web.UIModule)
+    ms =  get_members(__conf__.ACTION_DIR,member_filter=m_filter)
+    if 'tornado.web.UIModule' in ms:
+        del ms['tornado.web.UIModule']
+    
+    newms = {}
+    for key,val in ms.items():
+        newms[key.replace('.','_')] = val
+    
+    return newms
+
+def get_ui_methods():
+    """
+    return uimethod methods in ACTION_DIR
+    """
+    m_filter = lambda m: hasattr(m,'__reg_ui__') and m.__reg_ui__ ==True
+    ms =  get_members(__conf__.ACTION_DIR,member_filter=m_filter)
+    newms = {}
+
+    for key,val in ms.items():
+        newms[key.replace('.','_')] = val
+    
+    return newms
 
 class WebApp(object):
     settings = property(lambda self: __conf__.__dict__)
     handlers = property(lambda self: self._handlers)
+    uimodules = property(lambda self: self._modules)
+    uimethods = property(lambda self: self._methods)
     webapp = property(lambda self: self._webapp)
 
-    def __init__(self, port=None, callback=None):
+    def __init__(self, port=None, handlers=None, callback=None):
         self._port = port or __conf__.PORT
         self._callback = callback
         self._handlers = load_handlers(__conf__.ACTION_DIR)
+        self._modules = get_ui_modules()
+        self._methods = get_ui_methods()
         self._webapp = self._get_webapp()
+        __conf__.APP = self._webapp    
 
     def _get_webapp(self):
         settings = {"debug": __conf__.DEBUG,
@@ -30,6 +63,8 @@ class WebApp(object):
                     "template_path": app_path(__conf__.TEMPLATE_DIR_NAME),
                     "gzip": __conf__.GZIP,
                     "cookie_secret": __conf__.COOKIE_SECRET,
+                    "ui_modules":self.uimodules,
+                    "ui_methods":self.uimethods,
                     "xsrf_cookies": __conf__.XSRF_COOKIES}
 
         return tornado.web.Application(self._handlers, **settings)
@@ -66,11 +101,11 @@ def _get_opt():
 def run(callback=None):
     set_default_encoding()
     opts, args = _get_opt()
-    reflesh_config(opts.config)
+    refresh_config(opts.config)
 
     if opts.debug is not None:
         __conf__.DEBUG = opts.debug
 
-    WebApp(opts.port, callback).run()
+    WebApp(port=opts.port, callback=callback).run()
 
-__all__ = ["run", "WebApp"]
+__all__ = ["run", "WebApp","get_ui_modules","get_ui_methods"]
